@@ -5,7 +5,7 @@ import os, sys
 import paddle
 
 from .abc_interpreter import Interpreter
-from ..data_processor.readers import preprocess_image, read_image, restore_image, preprocess_inputs
+from ..data_processor.readers import preprocess_inputs, preprocess_save_path
 from ..data_processor.visualizer import visualize_overlay
 
 
@@ -25,14 +25,9 @@ class IntGradCVInterpreter(Interpreter):
         Initialize the IntGradCVInterpreter.
 
         Args:
-            paddle_model: A user-defined function that gives access to model predictions.
-                It takes the following arguments:
-
-                - data: Data input.
-                and outputs predictions. See the example at the end of ``interpret()``.22222
-            trained_model_path (str): The pretrained model directory.
+            paddle_model (callable): A paddle model that outputs predictions.
             use_cuda (bool, optional): Whether or not to use cuda. Default: True
-            model_input_shape (list, optional): The input shape of the model. Default: [3, 244, 244]
+            model_input_shape (list, optional): The input shape of the model. Default: [3, 224, 224]
 
         """
         Interpreter.__init__(self)
@@ -64,30 +59,6 @@ class IntGradCVInterpreter(Interpreter):
 
         :return: interpretations/gradients for images
         :rtype: numpy.ndarray
-
-        Example::
-
-            import interpretdl as it
-            def paddle_model(data):
-                class_num = 1000
-                model = ResNet50()
-                logits = model.net(input=data, class_dim=class_num)
-                probs = fluid.layers.softmax(logits, axis=-1)
-                return probs
-
-            img_path = 'assets/fireboat.png'
-
-            #https://github.com/PaddlePaddle/models/tree/release/1.8/PaddleCV/image_classification
-            ig = it.IntGradCVInterpreter(paddle_model, "assets/ResNet50_pretrained",
-                                         True)
-            gradients = ig.interpret(
-                img_path,
-                labels=None,
-                baselines='random',
-                steps=50,
-                num_random_trials=2,
-                visual=True,
-                save_path='assets/ig_test.jpg')
         """
 
         self.labels = labels
@@ -95,8 +66,10 @@ class IntGradCVInterpreter(Interpreter):
         if baselines is None:
             num_random_trials = 1
 
-        imgs, data, save_path = preprocess_inputs(inputs, save_path,
-                                                  self.model_input_shape)
+        imgs, data = preprocess_inputs(inputs, self.model_input_shape)
+
+        bsz = len(data)
+        save_path = preprocess_save_path(save_path, bsz)
 
         self.data_type = np.array(data).dtype
         self.input_type = type(data)
@@ -184,16 +157,9 @@ class IntGradNLPInterpreter(Interpreter):
         Initialize the IntGradInterpreter.
 
         Args:
-            paddle_model: A user-defined function that gives access to model predictions.
-                It takes the following arguments:
-
-                - data: Data input.
-                - alpha: A scalar for calculating the path integral
-                - baseline: The baseline input.
-                and outputs predictions. See the example at the end of ``interpret()``.
-            trained_model_path (str): The pretrained model directory.
+            paddle_model (callable): A paddle model that outputs predictions.
             use_cuda (bool, optional): Whether or not to use cuda. Default: True
-            model_input_shape (list, optional): The input shape of the model. Default: [3, 244, 244]
+            model_input_shape (list, optional): The input shape of the model. Default: [3, 224, 224]
 
         """
         Interpreter.__init__(self)
@@ -211,7 +177,7 @@ class IntGradNLPInterpreter(Interpreter):
         Main function of the interpreter.
 
         Args:
-            data (fluid.LoDTensor): The word ids input.
+            data (tuple or paddle.tensor): The inputs to the NLP model.
             label (list or numpy.ndarray, optional): The target label to analyze. If None, the most likely label will be used. Default: None.
             noise_amount (float, optional): Noise level of added noise to the embeddings.
                                             The std of Guassian random noise is noise_amount * (x_max - x_min). Default: 0.1
@@ -221,84 +187,6 @@ class IntGradNLPInterpreter(Interpreter):
 
         :return: interpretations for each word or a tuple of predicted labels, probabilities, and interpretations
         :rtype: numpy.ndarray or tuple
-
-        Example::
-
-            import interpretdl as it
-            import io
-            #Dataset: https://baidu-nlp.bj.bcebos.com/sentiment_classification-dataset-1.0.0.tar.gz
-            #Pretrained Model: https://baidu-nlp.bj.bcebos.com/sentiment_classification-1.0.0.tar.gz
-            def load_vocab(file_path):
-                vocab = {}
-                with io.open(file_path, 'r', encoding='utf8') as f:
-                    wid = 0
-                    for line in f:
-                        if line.strip() not in vocab:
-                            vocab[line.strip()] = wid
-                            wid += 1
-                vocab["<unk>"] = len(vocab)
-                return vocab
-
-            def paddle_model(data, alpha):
-                dict_dim = 1256606
-                emb_dim = 128
-                # embedding layer
-                emb = fluid.embedding(input=data, size=[dict_dim, emb_dim])
-                emb *= alpha
-                probs = bilstm_net_emb(emb, None, None, dict_dim, is_prediction=True)
-                return emb, probs
-
-            MODEL_PATH = "assets/senta_model/bilstm_model/"
-            PARAMS_PATH = os.path.join(MODEL_PATH, "params")
-            VOCAB_PATH = os.path.join(MODEL_PATH, "word_dict.txt")
-
-            ig = it.IntGradNLPInterpreter(paddle_model, PARAMS_PATH, True)
-
-            word_dict = load_vocab(VOCAB_PATH)
-            unk_id = word_dict["<unk>"]
-            reviews = [[
-                '交通', '方便', '；', '环境', '很好', '；', '服务态度', '很好', '', '', '房间', '较小'
-            ]]
-
-            lod = []
-            for c in reviews:
-                lod.append([word_dict.get(words, unk_id) for words in c])
-            base_shape = [[len(c) for c in lod]]
-            lod = np.array(sum(lod, []), dtype=np.int64)
-            data = fluid.create_lod_tensor(lod, base_shape, fluid.CPUPlace())
-
-            pred_labels, pred_probs, avg_gradients = ig.interpret(
-                data, label=None, steps=50, return_pred=True, visual=True)
-
-            sum_gradients = np.sum(avg_gradients, axis=1).tolist()
-            lod = data.lod()
-
-            new_array = []
-            for i in range(len(lod[0]) - 1):
-                new_array.append(
-                    list(zip(reviews[i], sum_gradients[lod[0][i]:lod[0][i + 1]])))
-
-            print(new_array)
-
-            true_labels = [1]
-            recs = []
-            for i, l in enumerate(new_array):
-                words = [t[0] for t in l]
-                word_importances = [t[1] for t in l]
-                word_importances = np.array(word_importances) / np.linalg.norm(
-                    word_importances)
-                pred_label = pred_labels[i]
-                pred_prob = pred_probs[i]
-                true_label = true_labels[0]
-                interp_class = pred_label
-                if interp_class == 0:
-                    word_importances = -word_importances
-                print(words, word_importances)
-                recs.append(
-                    VisualizationTextRecord(words, word_importances, true_label,
-                                            pred_label, pred_prob, interp_class))
-
-            visualize_text(recs)
         """
 
         if not self.paddle_prepared:
@@ -309,8 +197,7 @@ class IntGradNLPInterpreter(Interpreter):
         else:
             n = data.shape[0]
 
-        global alpha
-        alpha = 1
+        self._alpha = 1
         gradients, out, data_out = self.predict_fn(data, [0] * n)
 
         if labels is None:
@@ -321,6 +208,7 @@ class IntGradNLPInterpreter(Interpreter):
         labels = labels.reshape((n, ))
         total_gradients = np.zeros_like(gradients)
         for alpha in np.linspace(0, 1, steps):
+            self._alpha = alpha
             gradients, _, emb = self.predict_fn(data, labels)
             total_gradients += gradients
 
@@ -344,14 +232,11 @@ class IntGradNLPInterpreter(Interpreter):
 
             self.paddle_model.train()
 
-            global embedding
-            embedding = None
+            self._embedding = None
 
             def hook(layer, input, output):
-                global embedding
-                global alpha
-                output = alpha * output
-                embedding = output
+                output = self._alpha * output
+                self._embedding = output
                 return output
 
             for n, v in self.paddle_model.named_sublayers():
@@ -365,17 +250,16 @@ class IntGradNLPInterpreter(Interpreter):
             def predict_fn(data, labels):
                 global embedding
                 if isinstance(data, tuple):
-                    logits = self.paddle_model(*data)
-                    probs = paddle.nn.functional.softmax(logits, axis=1)
+                    probs = self.paddle_model(*data)
                 else:
-                    logits = self.paddle_model(data)
-                    probs = paddle.nn.functional.softmax(logits, axis=1)
+                    probs = self.paddle_model(data)
                 labels_onehot = paddle.nn.functional.one_hot(
                     paddle.to_tensor(labels), num_classes=probs.shape[1])
                 target = paddle.sum(probs * labels_onehot, axis=1)
                 gradients = paddle.grad(
-                    outputs=[target], inputs=[embedding])[0]
-                return gradients.numpy(), probs.numpy(), embedding.numpy()
+                    outputs=[target], inputs=[self._embedding])[0]
+                return gradients.numpy(), probs.numpy(), self._embedding.numpy(
+                )
 
         self.predict_fn = predict_fn
         self.paddle_prepared = True
